@@ -16,7 +16,7 @@
 */
 
 /*SH_doc
-title=ped section=1
+title=ped section=1 repnl=\040
 @name	ped
 @_brief	sed-style editer using peg
 @synopsis
